

set -ex



test -L $PREFIX/lib/libcupti.so
test -L $PREFIX/lib/libnvperf_host.so
test -L $PREFIX/lib/libnvperf_target.so
test -f $PREFIX/targets/x86_64-linux/include/cupti.h
test -L $PREFIX/targets/x86_64-linux/lib/libcupti.so
test -f $PREFIX/targets/x86_64-linux/lib/libnvperf_host.so
test -f $PREFIX/targets/x86_64-linux/lib/libnvperf_target.so
exit 0
